Sequences
=========

Symbol-mapping sequences
------------------------

.. python-apigen-group:: sequences-symbol-mapping

Correlation sequences
---------------------

.. python-apigen-group:: sequences-correlation

Linear recurrent sequences
--------------------------

.. python-apigen-group:: sequences-linear-recurrent

Maximum-length sequences
------------------------

.. python-apigen-group:: sequences-maximum-length
